
### Desc
---

> package template by LT


### Usage
---

install
> `pip3 install ltpackagetemplate`

upgrade
> `pip3 install --upgrade ltpackagetemplate`

use package as executable script
> `python3 -m ltpackagetemplate --mode releasemode`


### Find
---

find out where packages are:
> `pip3 -V`
>> `pip 19.0.2 from /usr/local/lib/python3.7/site-packages/pip (python 3.7)`
